==> kubernetes-model-discovery-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/discovery/v1beta1/EndpointPortBuilder.java <==
package io.fabric8.kubernetes.api.model.discovery.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class EndpointPortBuilder extends io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortFluentImpl<io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPort,io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortBuilder>{
  public EndpointPortBuilder() {
    this(false);
  }
  public EndpointPortBuilder(java.lang.Boolean validationEnabled) {
    this(new EndpointPort(), validationEnabled);
  }
  public EndpointPortBuilder(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortFluent<?> fluent) {
    this(fluent, false);
  }
  public EndpointPortBuilder(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new EndpointPort(), validationEnabled);
  }
  public EndpointPortBuilder(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortFluent<?> fluent,io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPort instance) {
    this(fluent, instance, false);
  }
  public EndpointPortBuilder(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortFluent<?> fluent,io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPort instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAppProtocol(instance.getAppProtocol()); 
    fluent.withName(instance.getName()); 
    fluent.withPort(instance.getPort()); 
    fluent.withProtocol(instance.getProtocol()); 
    this.validationEnabled = validationEnabled; 
  }
  public EndpointPortBuilder(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPort instance) {
    this(instance,false);
  }
  public EndpointPortBuilder(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPort instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAppProtocol(instance.getAppProtocol()); 
    this.withName(instance.getName()); 
    this.withPort(instance.getPort()); 
    this.withProtocol(instance.getProtocol()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPort build() {
    EndpointPort buildable = new EndpointPort(fluent.getAppProtocol(),fluent.getName(),fluent.getPort(),fluent.getProtocol());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EndpointPortBuilder that = (EndpointPortBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-discovery-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/discovery/v1beta1/EndpointPortBuilder.java <==
package io.fabric8.kubernetes.api.model.discovery.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class EndpointPortBuilder extends io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortFluentImpl<io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPort,io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortBuilder>{
  public EndpointPortBuilder() {
    this(false);
  }
  public EndpointPortBuilder(java.lang.Boolean validationEnabled) {
    this(new EndpointPort(), validationEnabled);
  }
  public EndpointPortBuilder(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortFluent<?> fluent) {
    this(fluent, false);
  }
  public EndpointPortBuilder(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new EndpointPort(), validationEnabled);
  }
  public EndpointPortBuilder(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortFluent<?> fluent,io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPort instance) {
    this(fluent, instance, false);
  }
  public EndpointPortBuilder(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortFluent<?> fluent,io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPort instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAppProtocol(instance.getAppProtocol()); 
    fluent.withName(instance.getName()); 
    fluent.withPort(instance.getPort()); 
    fluent.withProtocol(instance.getProtocol()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public EndpointPortBuilder(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPort instance) {
    this(instance,false);
  }
  public EndpointPortBuilder(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPort instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAppProtocol(instance.getAppProtocol()); 
    this.withName(instance.getName()); 
    this.withPort(instance.getPort()); 
    this.withProtocol(instance.getProtocol()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPortFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointPort build() {
    EndpointPort buildable = new EndpointPort(fluent.getAppProtocol(),fluent.getName(),fluent.getPort(),fluent.getProtocol());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EndpointPortBuilder that = (EndpointPortBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
